@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: horde/lib/Prefs/sql.php,v 1.27.2.21 2004/09/17 12:20:43 jan Exp $
+ * $Horde: horde/lib/Prefs/sql.php,v 1.27.2.16 2003/01/03 12:48:42 jan Exp $
  *
  * Copyright 1999-2003 Jon Parise <jon@horde.org>
  *
@@ -37,7 +37,7 @@
  *  );
  *
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.27.2.21 $
+ * @version $Revision: 1.27.2.16 $
  * @since   Horde 1.3
  * @package horde.prefs
  */
@@ -135,19 +135,15 @@ class Prefs_sql extends Prefs {
     /**
      * Retrieve a value or set of values for a specified user.
      *
-     * @since Horde 2.2
-     *
      * @access public
+     * @param          string $user    The user to retrieve prefs for.
+     * @param          mixed  $values  A string or array with the preferences to retrieve.
+     * @param optional string $scope   The preference scope to look in. Defaults to horde.
      *
-     * @param string $user            The user to retrieve prefs for.
-     * @param mixed $retrieve         A string or array with the preferences
-     *                                to retrieve.
-     * @param optional string $scope  The preference scope to look in.
-     *                                Defaults to horde.
+     * @return mixed  If a single value was requested, the value for that preference.
+     *                Otherwise, a hash, indexed by pref names, with the requested values.
      *
-     * @return mixed  If a single value was requested, the value for that
-     *                preference. Otherwise, a hash, indexed by pref names,
-     *                with the requested values.
+     * @since Horde 2.2
      */
     function getPref($user, $retrieve, $scope = 'horde')
     {
@@ -155,9 +151,9 @@ class Prefs_sql extends Prefs {
         $this->_connect();
 
         if ($scope != 'horde') {
-            $scope = "pref_scope = " . $this->db->quote($scope) . " OR pref_scope = 'horde'";
+            $scope = "'horde' OR pref_scope=" . $this->db->quote($scope);
         } else {
-            $scope = "pref_scope = 'horde'";
+            $scope = "'horde'";
         }
 
         if (is_array($retrieve)) {
@@ -168,9 +164,9 @@ class Prefs_sql extends Prefs {
                 }
                 $where .= 'pref_name=' . $this->db->quote($pref);
             }
-            return $this->db->getAssoc('SELECT pref_name, pref_value FROM ' . $this->_params['table'] . ' WHERE pref_uid=' . $this->db->quote($user) . ' AND (' . $where . ') AND (' . $scope . ')');
+            return $this->db->getAssoc('SELECT pref_name, pref_value FROM ' . $this->_params['table'] . ' WHERE pref_uid=' . $this->db->quote($user) . ' AND (' . $where . ') AND (pref_scope=' . $scope . ')');
         } else {
-            return $this->db->getOne('SELECT pref_value FROM ' . $this->_params['table'] . ' WHERE pref_uid=' . $this->db->quote($user) . ' AND pref_name=' . $this->db->quote($retrieve) . ' AND (' . $scope . ')');
+            return $this->db->getOne('SELECT pref_value FROM ' . $this->_params['table'] . ' WHERE pref_uid=' . $this->db->quote($user) . ' AND pref_name=' . $this->db->quote($retrieve) . ' AND (pref_scope=' . $scope . ')');
         }
     }
 
@@ -292,10 +288,6 @@ class Prefs_sql extends Prefs {
         /* Make sure we're connected. */
         $this->_connect();
 
-        /* Only use prepare/execute on Oracle, because it is broken in DB <1.6
-         * and DB >=1.6 requires PHP 4.2. */
-        $prepare = $this->params['phptype'] == 'oci8';
-
         /*
          * Loop through the "dirty" preferences.  If a row already exists for
          * this preference, attempt to update it.  Otherwise, insert a new row.
@@ -325,20 +317,11 @@ class Prefs_sql extends Prefs {
             if ($row && !DB::isError($row)) {
                 /* Update the existing row. */
                 $query = 'update ' . $this->params['table'] . ' ';
-                if ($prepare) {
-                    $query .= 'set pref_value = ?';
-                } else {
-                    $query .= 'set pref_value = ' . $this->db->quote((string)$this->getValue($name));
-                }
+                $query .= 'set pref_value = ' . $this->db->quote($this->getValue($name));
                 $query .= ' where pref_uid = ' . $this->db->quote($this->user);
                 $query .= ' and pref_name = ' . $this->db->quote($name);
                 $query .= ' and pref_scope = ' . $this->db->quote($scope);
-                if ($prepare) {
-                    $sth = $this->db->prepare($query);
-                    $result = $this->db->execute($sth,(string)$this->getValue($name));
-                } else {
-                    $result = $this->db->query($query);
-                }
+                $result = $this->db->query($query);
 
                 /* Return an error if the update fails. */
                 if (PEAR::isError($result)) {
@@ -350,14 +333,8 @@ class Prefs_sql extends Prefs {
                 $query .= '(pref_uid, pref_scope, pref_name, pref_value) values';
                 $query .= '(' . $this->db->quote($this->user) . ', ';
                 $query .= $this->db->quote($scope) . ', ' . $this->db->quote($name) . ', ';
-                if ($prepare) {
-                    $query .= '?)';
-                    $sth = $this->db->prepare($query);
-                    $result = $this->db->execute($sth,(string)$this->getValue($name));
-                } else {
-                    $query .= $this->db->quote((string)$this->getValue($name)) . ')';
-                    $result = $this->db->query($query);
-                }
+                $query .= $this->db->quote($this->getValue($name)) . ')';
+                $result = $this->db->query($query);
 
                 /* Return an error if the insert fails. */
                 if (PEAR::isError($result)) {
@@ -389,5 +366,6 @@ class Prefs_sql extends Prefs {
 
         parent::cleanup($all);
     }
-
 }
+
+?>
